# Demo

## Comparison 'less-broken' vs 'totally broken' workflow

We'll just look at 'strict' rules of `valn8n`. Run `valn8n check --strict-only lessbroken_3859-ai-customer-support-assistant-whatsapp-ready-works-for-any-business.json` which will result in one error (a wait between trials parameter apparently has a null value where it should have an int).

Now compare with the proken version: `valn8n check --strict-only broken_1521_Whatsapp_Stickynote_Automation_Webhook.json` which has 42 errors, 13 warnings. Ouch. Feel free to paste both workflows into the n8n editor to also see the difference there.

## Sources

### Broken workflow

`curl -L https://raw.githubusercontent.com/Zie619/n8n-workflows/main/workflows/Whatsapp/1521_Whatsapp_Stickynote_Automation_Webhook.json -o broken_1521_Whatsapp_Stickynote_Automation_Webhook.json`

### Less broken workflow

Downloaded on 15.03.2026 from: https://n8n.io/workflows/3859-ai-customer-support-assistant-whatsapp-ready-works-for-any-business/